#!/usr/bin/env python

import praw
import re
import string
import operator

function_words = [
	'about',
	'across',
	'against',
	'along',
	'around',
	'at',
	'behind',
	'beside',
	'besides',
	'by',
	'despite',
	'down',
	'during',
	'for',
	'from',
	'in',
	'inside',
	'into',
	'near',
	'of',
	'off',
	'on',
	'onto',
	'over',
	'through',
	'to',
	'toward',
	'under',
	'with',
	'within',
	'without',
	'I',
	'you',
	'he',
	'me',
	'her',
	'him',
	'my/mine',
	'her/hers',
	'his',
	'myself',
	'himself',
	'herself',
	'anything',
	'everything',
	'anyone',
	'everyone',
	'ones',
	'such',
	'it',
	'we',
	'they',
	'us',
	'them',
	'our/ours',
	'their/theirs',
	'itself',
	'ourselves',
	'themselves',
	'something',
	'nothing',
	'someone',
	'the',
	'some',
	'this',
	'that',
	'every',
	'all',
	'both',
	'one',
	'first',
	'other',
	'next',
	'many',
	'much',
	'more',
	'most',
	'several',
	'no',
	'a',
	'an',
	'any',
	'each',
	'no',
	'half',
	'twice',
	'two',
	'second',
	'another',
	'last',
	'few',
	'little',
	'less',
	'least',
	'own',
	'and',
	'but',
	'after',
	'when',
	'as',
	'because',
	'if',
	'what',
	'where',
	'which',
	'how',
	'than',
	'or',
	'so',
	'before',
	'since',
	'while',
	'although',
	'though',
	'who',
	'whose',
	'can',
	'may',
	'will',
	'shall',
	'could',
	'might',
	'would',
	'should',
	'must',
	'be',
	'do',
	'have',
	'here',
	'there',
	'today',
	'tomorrow ',
	'now',
	'then',
	'always',
	'never',
	'sometimes',
	'usually',
	'often',
	'therefore',
	'however',
	'besides',
	'moreover',
	'though',
	'otherwise',
	'else',
	'instead',
	'anyway',
	'incidentally',
	'meanwhile',
	'is',
	'are',
	'has',
	'had',
	'a',
	'b',
	'c',
	'd',
	'e',
	'f',
	'g',
	'h',
	'i',
	'j',
	'k',
	'l',
	'm',
	'n',
	'o',
	'p',
	'q',
	'r',
	's',
	't',
	'u',
	'v',
	'w',
	'x',
	'y',
	'z',
	'`',
	'~',
	'!',
	'@',
	'#',
	'$',
	'%',
	'^',
	'&',
	'*',
	'(',
	')',
	'_',
	'-',
	'=',
	'+',
	'[',
	']',
	'{',
	'}',
	';',
	':',
	'"',
	'\'',
	',',
	'.',
	'<',
	'>',
	'/',
	'?',
	'\\',
	'|'
	
]

seen = []
keywords = []

r = praw.Reddit(user_agent='AlienNewsTrends v0.1.3 by /u/BrandonMDowns')

def main():
	submissions = r.get_subreddit('news').get_hot(limit=100) #Hot 100 on /r/news
	for submission in submissions:
		title = submission.title
		title = re.sub(r'[^\w\-]+', ' ', title) #Remove non-alphanumeric
		title = re.sub(r'\s+', ' ', title).strip() #Remove excess white-space
		words = title.split() #Split into separate words by space
		for word in words:
			word = word.lower()
			if word in function_words:
				continue #do nothing
			elif word.isdigit():
				continue #do nothing
			elif word not in seen:
				seen.append(word) #Seen for first time
				keywords.append([word, 1])
			else:
				for pair in keywords:
					if pair[0] == word:
						pair[1] += 1 #Increment times seen

	keywords.sort(key=operator.itemgetter(1))
	keywords.reverse()

	i = 0
	for pair in keywords: #Print top 20 keywords
		if i < 20:
			print str(pair[0]) + ': ' + str(pair[1])
			i += 1

if __name__ == '__main__':
	main()
